@@ -132,7 +132,8 @@ class AgentLifeCycle:
                         args: populated argument namespace returned by `argparse.parse_args()`
 
         """
-        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        permission_docker_call_result = permission_safe_docker_call(
+            docker.from_env)
         if permission_docker_call_result is None:
             return False
         client = permission_docker_call_result
@@ -240,7 +241,7 @@ class AgentLifeCycle:
                 break
         print(output_text)
 
-    def _detached_restart(object,args):
+    def _detached_restart(object, args):
         """
         Runs _restart_protocol in detached mode with printing muted.
 
@@ -257,8 +258,7 @@ class AgentLifeCycle:
         sys.stdout = sys.__stdout__
         return result
 
-
-    def _restart_protocol(object,args):
+    def _restart_protocol(object, args):
         """
         Stops and starts the containers listed in `COG_AGENT_CONTAINERS`.
 
@@ -283,7 +283,7 @@ class AgentLifeCycle:
         if args.detach:
             result = True
             print("Running restart in detached mode")
-            p = Process(target=object._detached_restart,args=(args,))
+            p = Process(target=object._detached_restart, args=(args,))
             p.start()
         else:
             result = object._restart_protocol(args)
@@ -336,7 +336,8 @@ class AgentLifeCycle:
         # if list of agents is not specified, restart all
         if(not hasattr(args, 'list') or len(args.list) == 0):
             args.list = object._docker_container_names
-        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        permission_docker_call_result = permission_safe_docker_call(
+            docker.from_env)
         if permission_docker_call_result is None:
             return False
 
@@ -378,18 +379,25 @@ class AgentLifeCycle:
             "command": "/src/ecs_endpoint.py", "network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_streamer_api"] = {"command": "/src/streamer_endpoint.py", "volumes": {
             args.config.config_path + "agent/logs/bunched_logs": {"bind": "/root/.cognicept/agent/logs/bunched_logs", "mode": "rw"}}, "network_mode": "host"}
-        object._agent_run_options["remote_intervention_agent"] = {
-            "command": "rosrun remote_intervention_agent cognicept_agent_node", "network_mode": "host"}
+
         object._agent_run_options["health_aggregator"] = {"command": "roslaunch health_monitoring_aggregator aggregator.launch --wait", "volumes": {
             args.config.config_path + "health_config.yaml": {"bind": "/home/aggregator_ws/src/health_monitoring_aggregator/config.yml", "mode": "rw"}}, "network_mode": "host"}
 
+        # kriya run config
+        object._agent_run_options["remote_intervention_agent"] = {
+            "command": "", "network_mode": "host"}
         if(args.config.is_ssh_enabled()):
             object._agent_run_options["remote_intervention_agent"]["volumes"] = {
                 args.config.config_path + "ssh/id_rsa": {"bind": "/root/.ssh/id_rsa", "mode": "rw"}}
+        object._agent_run_options["kriya"] = object._agent_run_options["remote_intervention_agent"]
         object._agent_run_options["kriya_watchdog"] = {
-            "command": "python3 /home/watchdog.py","volumes": {
-            args.config.config_path + "kriya_logs/": {"bind": "/root/logs/", "mode": "rw"}, 
-            "/var/run/docker.sock/": {"bind": "/var/run/docker.sock/", "mode": "rw"}}}
+            "command": "python3 /home/watchdog.py", "volumes": {
+                args.config.config_path + "kriya_logs/": {"bind": "/root/logs/", "mode": "rw"},
+                "/var/run/docker.sock/": {"bind": "/var/run/docker.sock/", "mode": "rw"}}}
+
+        object._agent_run_options["kopilot"] = {"command": "", "network_mode": "host", "volumes": {
+            args.config.config_path + "kockpit.yaml": {"bind": "/root/config/kockpit.yaml", "mode": "rw"}}}
+
         object._agent_run_options["rosbridge"] = {
             "command": "roslaunch rosbridge_server rosbridge_websocket.launch", "network_mode": "host"}
         object._agent_run_options["test"] = {"command": "bash"}
@@ -397,7 +405,8 @@ class AgentLifeCycle:
             args.config.config_path + "bags/": {"bind": "/root/.cognicept/bags", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["other"] = {
             "command": "", "network_mode": "host"}
-        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        permission_docker_call_result = permission_safe_docker_call(
+            docker.from_env)
         if permission_docker_call_result is None:
             return False
         client = permission_docker_call_result
@@ -457,7 +466,7 @@ class AgentLifeCycle:
                         result (bool): True if succeeded
         """
         sts = subprocess.call(
-            ['sudo','sh','-c',"systemctl status datadog-agent", "-p"], shell=True, stdout=DEVNULL, stderr=DEVNULL)
+            ['sudo', 'sh', '-c', "systemctl status datadog-agent", "-p"], shell=True, stdout=DEVNULL, stderr=DEVNULL)
         if sts == 0:
             print("Health monitor status:" +
                   bcolors.OKBLUE + " ACTIVE" + bcolors.ENDC)
@@ -478,7 +487,8 @@ class AgentLifeCycle:
                         None
         """
         os.system("xhost +local:root")
-        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        permission_docker_call_result = permission_safe_docker_call(
+            docker.from_env)
         if permission_docker_call_result is None:
             return False
         client = permission_docker_call_result
@@ -576,7 +586,7 @@ class AgentLifeCycle:
         print("Info: Run `cognicept restart` to redeploy updated agents.")
         return success_flag
 
-    def _detached_update(object,args):
+    def _detached_update(object, args):
         """
         Runs the _update_protocol that pulls docker images listed in `COG_AGENT_IMAGES`.
 
@@ -596,7 +606,7 @@ class AgentLifeCycle:
 
         return result
 
-    def update(object,args):
+    def update(object, args):
         """
         Pulls docker images listed in `COG_AGENT_IMAGES`. Can be run in detached mode where printing is muted
 
@@ -614,6 +624,7 @@ class AgentLifeCycle:
             result = object._update_protocol(args)
 
         return result
+
     def _construct_ecr_client(object, config_obj):
         """
         Member utility function to create ECR client `object.ecr_client` based on runtime.env credentials
@@ -684,7 +695,7 @@ class AgentLifeCycle:
         # If the loop is completed, login failed, so return false
         return False
 
-    def display_version(object,args):
+    def display_version(object, args):
         """
         Display Cognicept-Shell version and docker images version
 
@@ -698,7 +709,7 @@ class AgentLifeCycle:
         # default value for version: "unknown/latest"
         for x in object._docker_images:
             image_data = object._docker_images[x].split(':')
-            if len(image_data)>1:
+            if len(image_data) > 1:
                 images_version.append(image_data[1])
                 image_data = []
             else:
@@ -706,4 +717,4 @@ class AgentLifeCycle:
         data['Version'] = images_version
         print("Cognicept Shell Version "+version)
         print(tabulate(data, headers='keys', tablefmt='psql'))
-        print("Runtime enviroment file directory: " +args.path)
+        print("Runtime enviroment file directory: " + args.path)
