@@ -9,6 +9,7 @@ from Crypto.PublicKey import RSA
 import subprocess
 import os
 import re
+import jwt
 import requests
 import getpass
 
@@ -443,7 +444,7 @@ class Configuration:
                         result (bool): True if succeeded
         """
         username = input('Username: ')
-        password = getpass.getpass()
+        password = getpass.getpass('Password: ')
         api_uri = object.get_cognicept_user_api_uri()
         try:
             x = requests.post(api_uri + 'user/login', json={'username': username, 'password': password})
@@ -451,6 +452,17 @@ class Configuration:
                 print('Failed to initialize the robot: Wrong credentials') 
             else:
                 auth_key = x.json()["access_token"]
+                # check whether whether user activate the 2FA
+                decode_json = jwt.decode(auth_key, verify=False, algorithms=["HS256"])
+
+                # False means 2FA Verification is activated by the user
+                if decode_json['user_claims']['authorized'] == False:
+                    new_key = object.mfa_verfication(api_uri,auth_key)
+                    if new_key == auth_key:    
+                        print("Failed to initialized robot: Invalid OTP entered 3 times")
+                        return False
+                    else:
+                        auth_key=new_key
 
                 r = requests.get(api_uri + 'spinup/config/' + args.org_id + '/' + args.robot_id, headers={'Authorization': 'Bearer {}'.format(auth_key)})
                 j = r.json()
@@ -473,6 +485,24 @@ class Configuration:
             print("Cognicept REST API error" + str(e))
             raise SystemExit()
 
+    def mfa_verfication(object,api_uri,auth_key):
+        otp_trial = 3
+        loop = True
+        while loop:
+            if otp_trial == 0:
+                key = auth_key
+                loop = False
+            else:
+                otp = getpass.getpass('OTP from Authenticator: ')
+                x = requests.post(api_uri + 'user/mfa/verify', headers={'Authorization': 'Bearer {}'.format(auth_key)}, json={'otp': otp})
+                if 'access_token' not in x.json():
+                    print('Invalid OTP! Please try again...')
+                else:
+                    key = x.json()["access_token"]
+                    loop = False
+            otp_trial -= 1
+        return key
+             
     def configure_autocomplete(object):
         """
 
